/*
 * Sven Kratz, Michael Rohs (c) 2011
 */
package de.lmu.mobilehci.gesturewizards;

import android.content.Context;
import android.graphics.Canvas;
import android.os.Handler;
import android.util.Log;
import android.view.ViewGroup.LayoutParams;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.view.animation.Animation.AnimationListener;
import android.widget.FrameLayout;
import android.widget.ImageView;

/**
 * An animated spell, basically just an animated image view. This is the
 * view-part of a spell in the MVC pattern.
 */
public class SpellView extends ImageView implements AnimationListener {

	// initial locations
	private Animation spellAnimation; 

	// the spell that is shown in this view
	public Spell spell; 
	
	public SpellView(Context context, Spell aSpell) {
		super(context, null);
		
		setLayoutParams(new LayoutParams(
	            LayoutParams.WRAP_CONTENT, 
	            LayoutParams.WRAP_CONTENT));
		
		spell = aSpell;
		
    	setImageResource(spell.spellInfo.imageResource);
    	
		spellAnimation = AnimationUtils.loadAnimation(context, spell.animationResource);	
		spellAnimation.setAnimationListener(this);
	}
	
	// start the animation
	public void animate() {
		Log.d("", "Beginning Animation!");
		startAnimation(spellAnimation);
	}

	protected void onDraw(Canvas c) {
		super.onDraw(c);
		// add custom drawing code if you want...
	}

	// if the animation has ended, remove this view from its parent view and make it disappear
	public void onAnimationEnd(Animation arg0) {
		Log.d("", "Animation Ended");

		// remove this spell view from parent view
		final FrameLayout parentView = (FrameLayout) getParent();
		if (parentView != null) {
			// The handler makes sure that the change of the GUI (removeView) is
			// done by the main thread and not the animation thread
			Handler h = new Handler();
			h.post(new Runnable() {
				public void run() {
					// remove spell from its superview (a FrameLayout in
					// gestureview.xml)
					parentView.removeView(SpellView.this);
				}
			});
		}
		
		spell.wizard.spellDidFinish(spell);
	}

	public void onAnimationRepeat(Animation arg0) {
		Log.d("", "Animation Repeted");
	}

	public void onAnimationStart(Animation arg0) {
		Log.d("", "Animation Started");
	}

}
